from .Base import *

EventHub.connection_string = "Endpoint=sb://storis-eventhub-devel.servicebus.windows.net/;SharedAccessKeyName=SendAndListenAccessPolicy;SharedAccessKey=bGdkSFKIdnWx3eIJ0OXzIYG18WZgKQM46z6gWP/OHc8=;EntityPath=ingestion"
EventHub.name = "ingestion"



import argparse, asyncio, json
from EventHub import Event
from Settings import Environment

def run(event_type):
    loop = asyncio.new_event_loop()
    asyncio.set_event_loop(loop)
    loop.run_until_complete(send_events(event_type))

async def send_events(event_type):
    events = (json.loads(args.events))
    #print(events)    
    client_code = args.code
    await Event.run(event_type, client_code, events)


#Declare script parameters
parser = argparse.ArgumentParser()
parser.add_argument("--env", help="Sets environment. Development, Production, QA or Learn", type=str)
parser.add_argument("--code", help="Sets Storis client code", type=str)
parser.add_argument("--events", help="Sets Storis client code")

args = parser.parse_args()

#Set environment
Environment.set_environment(args.env)


    



import os

def get_environment():
    env = os.getenv('APP_ENVIRONMENT')
    if env == None:
        raise Exception("Environment is not set. Set Production or Development by calling 'python Environment.py <env_name>'")
    return env

def set_environment(envirment_name):
    os.environ['APP_ENVIRONMENT'] = envirment_name
    print('Environment is set to -> ' + os.getenv('APP_ENVIRONMENT'))




from Settings import Development, Production, Learn, Staging, Environment, Constants

def get():
    return {
        Constants.DEVELOPMENT: Development,
        Constants.PRODUCTION: Production,
        Constants.LEARN: Learn,
        Constants.QA: Staging
    }[Environment.get_environment()]
